@@ -38,7 +38,14 @@ class BitbucketCloudBase(BitbucketBase):
         return links[link]["href"]
 
     def _get_paged(
-        self, url, params=None, data=None, flags=None, trailing=None, absolute=False, paging_workaround=False
+        self,
+        url,
+        params=None,
+        data=None,
+        flags=None,
+        trailing=None,
+        absolute=False,
+        paging_workaround=False,
     ):
         """
         Used to get the paged data
